@@ -278,7 +278,7 @@ C*****************************
 
       DIMENSION sig_res(9)
 
-!       external breitwigner, Ef, singleback, twoback
+c       external breitwigner, Ef, singleback, twoback
 
        DATA sth /1.1646D0/
 
@@ -1292,7 +1292,7 @@ C**********************************************************************
       COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
       COMMON /SS_CHP/ S_LIFE(49), ICHP(49), ISTR(49), IBAR(49)
       COMMON /SS_MASS1/ AM(49), AM2(49)
-      COMMON /S_CFLAFR/ PAR(8)
+      COMMON /SS_CFLAFR/ PAR(8)
       SAVE
 
       DIMENSION P_dec(10,5), P_in(5)
@@ -2067,10 +2067,10 @@ C**********************************************************************
 
       COMMON /SS_RUN/ SQS, S, Q2MIN, XMIN, ZMIN, kb, kt, a1, a2, Nproc
       COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
-      COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+      COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
       COMMON /SS_CHP/ S_LIFE(49), ICHP(49), ISTR(49), IBAR(49)
       COMMON /SS_MASS1/ AM(49), AM2(49)
-      COMMON /S_CNAM/ NAMP (0:49)
+      COMMON /SS_CNAM/ NAMP (0:49)
       CHARACTER*6 NAMP
       CHARACTER CODE*18
       SAVE
@@ -2147,10 +2147,10 @@ C***********************************************************************
 
       COMMON /SS_RUN/ SQS, S, Q2MIN, XMIN, ZMIN, kb, kt, a1, a2, Nproc
       COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
-      COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+      COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
       COMMON /SS_CHP/ S_LIFE(49), ICHP(49), ISTR(49), IBAR(49)
       COMMON /SS_MASS1/ AM(49), AM2(49)
-      COMMON /S_CNAM/ NAMP (0:49)
+      COMMON /SS_CNAM/ NAMP (0:49)
       CHARACTER*6 NAMP
       SAVE
 
@@ -2294,7 +2294,7 @@ C***********************************************************************
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       IMPLICIT INTEGER (I-N)
 
-      COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+      COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
       COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
       COMMON /SSS_PLIST1/ LLIST1(2000)
       SAVE
@@ -2348,7 +2348,7 @@ C***********************************************************************
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       IMPLICIT INTEGER (I-N)
 
-       COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+       COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
       COMMON /SS_MASS1/ AM(49), AM2(49)
       SAVE
 
@@ -3018,7 +3018,7 @@ c         moved from eventgen (KK)
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       SAVE
 c... declare stable particles:
-       COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+       COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
 C  muons stable
       IDB(4) = -ABS(IDB(4))
       IDB(5) = -ABS(IDB(5))
@@ -3072,15 +3072,15 @@ c***************************
 c** last change: 12/10/98 **
 c** author:      A.Muecke **
 c***************************
-      BLOCK DATA DATDEC
+      BLOCK DATA DATDEC_KK
       IMPLICIT DOUBLE PRECISION (A-H,O-Z)
       IMPLICIT INTEGER (I-N)
       SAVE
        COMMON /SS_PLIST/ P(2000,5), LLIST(2000), NP, Ideb
-       COMMON /S_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
+       COMMON /SS_CSYDEC/ CBR(102), IDB(49), KDEC(612), LBARP(49)
       COMMON /SS_MASS1/ AM(49), AM2(49)
       COMMON /SS_CHP/  S_LIFE(49), ICHP(49), ISTR(49), IBAR(49)
-      COMMON /S_CNAM/ NAMP (0:49)
+      COMMON /SS_CNAM/ NAMP (0:49)
 
       CHARACTER NAMPRESp*6
       COMMON /RES_PROPp/ AMRESp(9), BGAMMAp(9),WIDTHp(9),  
@@ -3295,7 +3295,7 @@ C************************** settings of versions 1.4 - 2.0 *********
      + 0.,0.,0./
       END
 C->
-      BLOCK DATA PARAM_INI
+      BLOCK DATA PARAM_INI_KK
 C....This block data contains default values
 C.   of the parameters used in fragmentation
 C................................................
@@ -3308,7 +3308,7 @@ C................................................
       COMMON /SS_CPSPL/ CCHIK(3,6:14)
       COMMON /SS_CQDIS/ PPT0 (33),ptflag
       COMMON /S_CDIF0/ FFD, FBD, FDD
-      COMMON /S_CFLAFR/ PAR(8)
+      COMMON /SS_CFLAFR/ PAR(8)
 C...Longitudinal Fragmentation function
       DATA FA /0.5/, FB0 /0.8/
 C...Longitudinal Fragmentation function for leading baryons
