@@ -98,6 +98,77 @@ contains
          sampInfo(n)%sum,  sampInfo(n)%coef2 )
   end subroutine csampAF0
 
+  subroutine csampAF0_b(iowk, filen, sampInfoNo)
+!     same as csampAF0 but assumes only for getting function
+!     value by interpolation. (say, for function with negative values)
+    implicit none
+    integer,intent(in)::iowk  !  file logical number temporarily used
+    character(len=*),intent(in)::filen  ! file name which contains (x,dn/dx)
+    integer,intent(out)::sampInfoNo  ! the distributions defined so far
+                                       ! this is sampInfoNo-th one
+                                       ! so you can spcify the distribution
+                   ! by sampInfoNo or directly manipulate by
+                   ! sampInfo(sampInfoNo) 
+!      type(sampAF),intent(out)::sampInfo  ! distribution info is stored
+
+    integer::icon
+    integer::i, n, nrow
+
+    real(8):: x, y
+
+    call copenf(iowk, filen, icon)
+    if(icon /= 0 ) then
+       write(0,*) ' error '
+       write(0,*) 'file: ',filen
+       write(0,*) ' could not be opened'
+       stop
+    endif
+    i = 0
+    call cskipComment(iowk, icon)
+    if(icon /= 0 ) stop
+!          first count the # of  data      
+    do while ( .true. )
+       read(iowk, *, end=100) x, y
+       i  = i + 1
+    enddo
+100 continue
+    nrow = i
+! ////////////
+!      write(0, *) ' nrow=', nrow
+! ////////////
+    if( sampInfoNoCounter >= maxsampAF ) then
+       write(0,*) ' too many funcitons defined by tables > ', maxsampAF
+       write(0,*) ' increase  maxsampAF in csampAF in Cosmos/cosmos'
+       stop
+    endif
+    sampInfoNoCounter = sampInfoNoCounter +1
+    sampInfoNo = sampInfoNoCounter  
+    n = sampInfoNo
+!   allocate memory
+    allocate(sampInfo(n)%x(nrow))
+    allocate(sampInfo(n)%y(nrow))
+    allocate(sampInfo(n)%yi(nrow))
+    allocate(sampInfo(n)%coef(nrow,1))
+    allocate(sampInfo(n)%coef(nrow,2))
+    allocate(sampInfo(n)%coef(nrow,3))
+!    allocate(sampInfo(n)%coef2(nrow,1))
+!    allocate(sampInfo(n)%coef2(nrow,2))
+!    allocate(sampInfo(n)%coef2(nrow,3))
+
+    rewind(iowk)
+    call cskipComment(iowk, icon)
+    
+    do i =1 , nrow
+       read(iowk, *, end=200) sampInfo(n)%x(i), sampInfo(n)%y(i)
+    enddo
+200 continue
+    close(iowk)
+    sampInfo(n)%n = nrow
+
+    call ksampAF0_b(sampInfo(n)%x, sampInfo(n)%y, sampInfo(n)%n, &
+         sampInfo(n)%coef, sampInfo(n)%n)
+  end subroutine csampAF0_b
+
 
   subroutine  csampAF0byArray(x, y, nrow, sampInfoNo)
 !   This purpose is the same as csampAF0. the input is not
@@ -138,6 +209,46 @@ contains
          sampInfo(n)%sum,  sampInfo(n)%coef2 )
   end subroutine csampAF0byArray
 
+  subroutine  csampAF0byArray_b(x, y, nrow, sampInfoNo)
+!   This purpose is the same as csampAF0byArray but 
+!    not from file but from array and assumes
+!    only for  getting function value by interpolation.
+
+    implicit none
+    integer,intent(in)::nrow  !  number of data in (x,y)
+    real(8),intent(in)::x(nrow), y(nrow)  ! input data array
+    integer,intent(out)::sampInfoNo  ! the distributions defined so far
+
+    integer::n
+
+    if( sampInfoNoCounter >= maxsampAF ) then
+       write(0,*) ' too many funcitons defined by tables > ', maxsampAF
+       write(0,*) ' increase  maxsampAF in csampAF in Cosmos/cosmos'
+       stop
+    endif
+    sampInfoNoCounter = sampInfoNoCounter +1
+    sampInfoNo = sampInfoNoCounter  
+    n = sampInfoNo
+!   allocate memory
+    allocate(sampInfo(n)%x(nrow))
+    allocate(sampInfo(n)%y(nrow))
+    allocate(sampInfo(n)%yi(nrow))
+    allocate(sampInfo(n)%coef(nrow,1))
+    allocate(sampInfo(n)%coef(nrow,2))
+    allocate(sampInfo(n)%coef(nrow,3))
+!    allocate(sampInfo(n)%coef2(nrow,1))
+!    allocate(sampInfo(n)%coef2(nrow,2))
+!    allocate(sampInfo(n)%coef2(nrow,3))
+
+    sampInfo(n)%n = nrow
+      ! copy data
+    sampInfo(n)%x = x
+    sampInfo(n)%y = y
+    
+    call ksampAF0_b(sampInfo(n)%x, sampInfo(n)%y, sampInfo(n)%n, &
+         sampInfo(n)%coef, sampInfo(n)%n)
+  end subroutine csampAF0byArray_b
+
 
   subroutine csampAF(n, xs)
     implicit none
@@ -350,5 +461,24 @@ contains
        sampInfo(n)%integ = 0
     endif
   end subroutine csampAFdealloc
+  subroutine  csampAFdealloc_b(n)
+    implicit none
+    integer,intent(in)::n  ! id # of the function
+    
+    deallocate(sampInfo(n)%x)
+    deallocate(sampInfo(n)%y)
+    deallocate(sampInfo(n)%yi)
+    deallocate(sampInfo(n)%coef)
+
+
+    if( sampInfo(n)%invf == 1 ) then 
+       deallocate(sampInfo(n)%icoef)
+       sampInfo(n)%invf = 0
+    endif
+    if( sampInfo(n)%integ == 1) then
+       deallocate(sampInfo(n)%igcoef)
+       sampInfo(n)%integ = 0
+    endif
+  end subroutine csampAFdealloc_b
 
 end module modcsampAF
