@@ -13,6 +13,9 @@ c             3) for interacting nucleons, calls  chAcol to make
 c                multiple production.
 c
         subroutine cheavyInt(pj, ia, iz,  a, ntp)
+#if !defined (MacIFC)
+        use modXsecMedia
+#endif
         implicit none
 
 #include  "Zcode.h"
@@ -63,9 +66,24 @@ c         call ctestOnShell(' heavy bef frag', pj)
 c         sumerg = 0.
 c         ////
 
-c////////////
-c        call cqEventNo(cumev, cev)
-c//////////////////
+!     
+! MacIFC  ld error  ; also for TargetXs here and chAcol.f)
+!  (No error when complile ephook.f but for
+!   testCnf1.mk error occurs)
+!////        integer:: dummy
+!///         dummy = TargetNucleonNo
+!Undefined symbols for architecture x86_64:
+!  "_modxsecmedia_mp_targetnucleonno_", referenced from:
+!      _cheavyint_ in libcosmos.a(cheavyInt.o)
+!  "_modxsecmedia_mp_targetxs_", referenced from:
+!      _cheavyint_ in libcosmos.a(cheavyInt.o)
+!      _chacolx_ in libcosmos.a(chAcol.o)
+!ld: symbol(s) not found for architecture x86_64
+!c//////////////////
+#if defined (MacIFC)
+#include "Zworkaround.h"
+#endif
+
         ntp=0
 c
 c            ** fragmentation with some nucleon interaction **
@@ -89,7 +107,7 @@ c     *      ( pj.code .eq. ktriton .or. pj.code .eq. kdeut) ) then
         elseif(ActiveMdl .eq. 'qgsjet2') then
            call cQGSjet(pj, ia, iz, a, ntp)
         elseif(ActiveMdl .eq. 'epos') then
-           call ceposGenOneEvent(a, ntp)
+           call ceposGenOneEvent(pj, ia, iz, a, ntp)
         elseif(ActiveMdl .eq. 'gheisha' .and.
      *        pj.code .eq. kgnuc  .and. (pj.subcode .eq. 2 .or.
      *        pj.subcode .eq. 3) ) then
