@@ -4,7 +4,7 @@
       record /ptcl/ pj  !  input. projectile
       record /ptcl/ a(1000)
       integer ia, iz, ntp, i, now(2)
-      real*8 sig, tgA
+      real*8 sig, tgA, tgZ
 
       call cmkSeed(0, now)   ! make seed using timer and hostname            
       call rnd1r(now)
@@ -17,7 +17,8 @@
       ia = 207
       iz =  82
       tgA = ia
-      call cinelx(pj,  tgA, sig)
+      tgZ = tgA*0.4  ! if pj is not heavy, can be arbitrary.
+      call cinelx(pj,  tgA, tgZ, sig)
       call cjamEvent(pj, ia, iz, sig, a, ntp)
       do i = 1, ntp
          write(*,*) i, a(i).code, a(i).charge, a(i).fm.p(4)
