@@ -133,21 +133,22 @@ c      compute Xprimary, Yprimary, Zprimary in 'xyz' system.
 
       real*8  temp
 c      
-      Zprimary.r(1) = - DcAtObsXyz.r(1)
-      Zprimary.r(2) = - DcAtObsXyz.r(2)
-      Zprimary.r(3) = - DcAtObsXyz.r(3)
+      Zprimary.r(:) = - DcAtObsXyz.r(:)
       call cvecProd(Zprimary, DetZaxis, Xprimary)
 c         see if Zprimary // DetZaxis; if so reset Xprimary
-      temp= Xprimary.r(1)**2 + Xprimary.r(2)**2 + Xprimary.r(3)**2
+      temp= sum( Xprimary.r(:)**2 )
       if(temp .lt. 1.e-12) then
          Xprimary = DetXaxis
       else
          temp =sqrt(temp)
-         Xprimary.r(1) = Xprimary.r(1)/temp
-         Xprimary.r(2) = Xprimary.r(2)/temp
-         Xprimary.r(3) = Xprimary.r(3)/temp
+         Xprimary.r(:) = Xprimary.r(:)/temp         
       endif
       call cvecProd(Zprimary, Xprimary, Yprimary)
+      Txyz2prim(1,:) = Xprimary.r(:)
+      Txyz2prim(2,:) = Yprimary.r(:)
+      Txyz2prim(3,:) = Zprimary.r(:)
+      Tprim2xyz(:,:) = transpose(Txyz2prim(:,:))
+       
       end
 c     ******************************
       subroutine csetObsZ(converter)
@@ -206,7 +207,18 @@ c         as a track of the primary.
       
       ptrack = Zfirst
       end
-
+      subroutine cqFirstColMedia(A, Z, xs)
+!        retrns first col. element and Xsecion on it
+      implicit none
+#include "Ztrack.h"
+#include "Ztrackv.h"
+      integer,intent(out):: A
+      integer,intent(out):: Z
+      real(8),intent(out):: xs
+      A = FirstColA
+      Z = FirstColZ
+      xs = FirstColXs
+      end
 c --------------------------------
       subroutine ciniASObs
       implicit none
