@@ -26,6 +26,14 @@ c           get one particle from stack
          if(moreptcl .eq. 0) goto 100   !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
+c//////////
+c         if( icon /= 0 .and.  
+c     *      TrackBefMove.p.fm.p(4)-TrackBefMove.p.mass > 0.05 ) then
+c            write(0,*) ' H.E dead icon=',icon
+c            stop
+c         endif
+c//////////////
+            
 c                     icon=0; alive, 1 E<Emin, 2 long flight 3 h>H 4 h<L
 c                             5 angle>limit
 c            AS generation. 
@@ -70,6 +78,8 @@ c             already dead ptcl has been considered in cifDead; nothing todo
       end
 c -------------------------------------tracking a ptcl
       subroutine cTracking
+      use modXsecMedia, only: TargetNucleonNo, TargetProtonNo,
+     * TargetXs
       implicit none
 
 #include  "Ztrack.h"
@@ -82,10 +92,11 @@ c -------------------------------------tracking a ptcl
 #include  "Zcode.h"
 #include  "Zmanagerp.h"
 #include  "Zstackv.h"
+#include  "Zevhnv.h"
 c                next is for DEBUG
 c//////
-      logical deb
-      common /cdebug/ deb
+      logical show
+      common /showshow/ show
 c/////////
 #define DEBUG 0
 
@@ -117,8 +128,21 @@ c           Truncate the path if it is too long. Note, the truncated
 c           path in the above process may be again truncated to
 c           a shorter one. This happens, for example, if ptcl energy
 c           is low.  Path inf is reset in IntInfArray.
+c///////////
+      if(show) then
+         write(0,*) ' bef truncpath'
+         write(0,*) ' MoveStat=',MoveStat
+      endif
+c//////////////
       call ctruncPath
 
+c///////////
+      if(show) then
+         write(0,*) ' bef truncpath'
+         write(0,*) ' MoveStat=',MoveStat
+      endif
+c//////////////
+
 #if DEBUG == 1
       call checkstat('after ctruncPath')
 #endif
@@ -127,6 +151,12 @@ c           compute path end inf. including scattering and
 c           mag. deflection.  Path end inf is set in MovedTrack
 
       call ccompPathEnd
+c///////////
+      if(show) then
+         write(0,*) ' afte ccompPathend'
+         write(0,*) ' MoveStat=',MoveStat
+      endif
+c//////////////
 
 #if DEBUG == 1
       call checkstat('after ccompPathEnd')
@@ -156,7 +186,12 @@ c               4th arg. not used now
 c            the user may kill the ptcl
       call cobservation(8)
 #endif
-
+c//////////
+      if(show) then
+         write(0,*) ' MoveStat=',MoveStat, Truncated
+         write(0,*) ' ToInteract', ToInteract
+      endif
+c/////////////////
 
 c     
       if(MoveStat .eq. Truncated) then
@@ -203,6 +238,9 @@ c                  comment out from v6.31
 c               call cresetTimer(MovedTrack)
 
                Zfirst = MovedTrack
+               FirstColA = TargetNucleonNo
+               FirstColZ = TargetProtonNo
+               FirstColXs = TargetXs
             endif
          endif
 #if DETAILED_TRACKING >= 1 
@@ -212,9 +250,17 @@ c               call cresetTimer(MovedTrack)
 #if DEBUG == 1
          call checkstat('before cinteraction')
 #endif
-
+c//////////////
+         if(show) then
+            write(0,*) 'e ntering interaction'
+         endif
+c/////////////////
          call cinteraction
-
+c////////
+         if(show) then
+            write(0,*) 'back from cinerac'
+         endif
+c//////////////
 
 
       elseif(MoveStat .eq. ToBeObserved ) then
@@ -395,6 +441,7 @@ c
 
 c     --------------------------------------------------
       subroutine csampIntL
+      use modXsecMedia
 c     **************************************************
 c          
 c          sample interaction length 
@@ -428,6 +475,10 @@ c                is set.
 
       real*8 leng/1.d50/   ! will  be truncated  by ctruncPath
       integer:: jcon
+c/////////
+      logical::show
+      common /showshow/ show
+c//////////
 
 c     **************************************************
       call ciniSmpIntL   ! init for interaction length sampling
@@ -444,7 +495,18 @@ c
             call csampNEPIntL   ! non Electron Photon  Interaction.
          endif
          call cfixProc
-
+c///////////////
+         if( TrackBefMove.p.code == 6 .and.
+     *       TrackBefMove.p.charge == -1 .and.
+     *     (  TrackBefMove.p.fm.p(4)-TrackBefMove.p.mass < 
+     *         0.1 ) ) then
+            show = .true.
+            write(0,*) ' fix proc =',
+     *        IntInfArray(ProcessNo).process
+         else
+            show = .false.
+         endif
+c//////////////////
          if( IntInfArray(ProcessNo).process == 'coll' ) then
 !               some of the code can not deal with coll.of sigma 
 !               etc.
@@ -452,7 +514,18 @@ c
             if( jcon == -1) then
 !                  then force to decay
                call cresetIntInf
+            else
+               call cfixTarget( media(1) )
+c///////////////
+               if(show) then
+                  write(0,*)' TargetNucleonNo=',TargetNucleonNo
+               endif
+c///////////////////
             endif
+         elseif( IntInfArray(ProcessNo).process == 'photop') then
+            call  cfixTarget( media(1) )
+         elseif( IntInfArray(ProcessNo).process == 'munuci') then
+            call cfixTargetMuNI(media(1))
          endif
 
          if(.not. Freec .and. Zfirst.pos.depth .eq. 0.) then
@@ -564,13 +637,20 @@ c        an observation depth.
 
       real*8 leng, thick
 c
+c//////////////////
+      logical show
+      common /showshow/ show
+c////////////
       call cmaxMovLen(leng, thick)
 c//////////
-c      write(0,*) ' after maxMovLen, leng=',leng, ' thick=',thick
-c      write(0,*) '  IntInfArray.length=',IntInfArray(ProcessNo).length
-c      write(0,*) ' procno=', ProcessNo, ' process=', 
-c     *   IntInfArray(ProcessNo).process
+      if(show) then
+       write(0,*) ' after maxMovLen, leng=',leng, ' thick=',thick
+       write(0,*) '  IntInfArray.length=',IntInfArray(ProcessNo).length
+       write(0,*) ' procno=', ProcessNo, ' process=', 
+     *   IntInfArray(ProcessNo).process
+      endif
 cc//////////
+
       if(leng .lt. IntInfArray(ProcessNo).length ) then
          MoveStat = Truncated
          IntInfArray(ProcessNo).length = leng
