@@ -1,5 +1,6 @@
+
       module SoftenPiK
-c         This part is common to Cosmos(modifyX) and Epics(Gencol)
+c         This part is common to Cosmos(modifyX) and Cosmos/Util/Gencol
 c     Used to soften the x-distribution.     
       implicit none
 
@@ -13,7 +14,7 @@ c mode=3)      soften pi/K/eta  spectrum;
 c              If their x is >  x>xth, this is applied.
 c              (except for the leading pi/K when
 c              incident is pi/K).
-c mode=-3      probabilty of softening depends on the user's algorithm
+c mode=-3      probability of softening depends on the user's algorithm
 c              The user must modify cJudegeSplit.
 c    trial version method          
 c              If we find a pi/K/eta with x>xth,
@@ -44,14 +45,15 @@ c
 
       real(8),save:: E0th = 500.   !  500 GeV  over this we apply cut/mod.
                            !  if make this 10 TeV, effect after shower max
-                           !  decreases even for  E1ry=10^19 eV
+                           !  decreases even for  E1ry=10^19 eV.  
+                           !  This is in lab. frame
       integer,save:: fwbw = 3    ! Used in Gencol; modification is applied to
                                  ! 1--> forward only 2--> backword only
                                  ! 3--> both ; However, 1 is used when
                      ! Cosmos output (in cms) is the target, irespectively of
                      ! fwbw.  
       logical,save:: special=.false.  ! This is used olny in modifyX of
-                     !   Cosmos. but not used in Gencol of Epics.
+                     !   Cosmos. but not used in Gencol.
                      !   In Cosomos, it is used to see the x-dist. of
                      !   pi, K, eta  at the first interaction; 
                      ! For that, make this  .ture. and 
@@ -93,7 +95,13 @@ c
                 !  converting the energy into cms system, and then
                 !   re-boosted to Lab.  
                 !  
+      real(8),save:: k1u=0.25    !   
+      real(8),save:: xthl=1.d0
+      real(8),save:: xthu=10.d0
+      real(8),save:: rejpw=0.
       logical,save:: modified   ! not input. used in Cosmos
+      real(8),save:: E0lab=1.e12   ! not input. current E0 in lab. 
+                                ! frame. Used in Cosmos
 
 !             next one is about 0.6 of maxn in Epics/Util/Gencol/Zprivate.h
 !             but this  cannot inherit maxn
@@ -107,7 +115,7 @@ c--------------------------------------------------------------------
 !         judge if this x should be split
 #include "Zptcl.h"
       record /ptcl/ pj    ! input. projectile. you may use this
-      real(8),intent(in):: x
+      real(8),intent(in):: x  ! KE ratio
       logical,intent(out):: split  ! .true.  or .false.. if true, split meson
 
       real(8):: u
@@ -179,18 +187,25 @@ c
       endif
 
       nnow = nin
-
+      xth = csoftenFixXth(E0lab)
+      k1u = ck1u(E0lab)
+      xthu =cxthu(E0lab)
       do i = 1, nrepeat
          call csoftenPiK0(inciptcl, pstore, nnow, nout, exist)
          if( exist == 0 ) exit 
          nnow = nout
       enddo
+      do i = 1, 1
+         call csoftenPiK1(inciptcl, pstore, nnow, nout, exist)
+         if( exist == 0 ) exit 
+         nnow = nout
+      enddo
       end   subroutine csoftenPiK
 
 
       subroutine csoftenPiK0(inciptcl, pstore, nin, nout, exist)
-c         inciptcl made a collsion and generated nin particles in pstore
-c         particle information may be at CMS or Lab.
+c         inciptcl made a collision and generated nin particles in pstore
+c         particle.  information may be at CMS or Lab.
 c     If we want to  make the x-dist. softer,
 c      A) For Cosmos (air target),  we may use the Lab system
 c         (for large X, the distribution would be the same 
@@ -219,11 +234,10 @@ C ----------------------------------------------
       integer:: nw, icon
       logical:: split 
 
-      E0 = inciptcl.fm.p(4)
+      E0 = inciptcl.fm.p(4) - inciptcl.mass
       nout = nin
       exist = 0
-
-      if(E0 < E0th) return      !!!!!
+      if( E0lab < E0th) return      !!!!!
       nc = nin
 c            if pi/K is incident, regards the highest one as leading
 c            and avoid to modify 
@@ -237,7 +251,7 @@ c              find max energy ptcl index and E; eta cannot be incident
       endif
 
       do i = 1, nin
-         x = pstore(i).fm.p(4)/E0
+         x = (pstore(i).fm.p(4)-pstore(i).mass)/E0
          if( abs(mode) == 3 ) then
             if( i /= maxi ) then
 c                softening
@@ -258,11 +272,11 @@ c                softening
                      ! split;  if impossilbe, do nothing
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E1
+                        work(nw).fm.p(4) = E1 + work(nw).mass 
                         call cae2p(work(nw)) ! adjust momentum
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E2
+                        work(nw).fm.p(4) = E2 + work(nw).mass 
                         call cae2p(work(nw))
 !                       original one is replaced by E1
                         pstore(i) = work(1)
@@ -313,12 +327,148 @@ c               do nothing
       endif
       end subroutine csoftenPiK0
 
+
+      subroutine csoftenPiK1(inciptcl, pstore, nin, nout, exist)
+c         inciptcl made a collision and generated nin particles in pstore
+c         particle.  information may be at CMS or Lab.
+c     If we want to  make the x-dist. softer,
+c      A) For Cosmos (air target),  we may use the Lab system
+c         (for large X, the distribution would be the same 
+c           as CMS)
+      implicit none
+#include  "Zcode.h"
+#include  "Zptcl.h"
+
+      record /ptcl/inciptcl  ! input. incident ptcl at collision
+c                  
+      integer,intent(in)::nin ! # of ptcls in pstore 
+      record /ptcl/pstore(*)  ! input/output.   ptcls to be softened.
+                           !     Softened ones are put here
+      integer,intent(out)::nout ! # of ptcls re-stored in pstore 
+      integer,intent(out)::exist  ! # of particcls with X> Xth
+C ----------------------------------------------
+      record /ptcl/work(2)
+      logical  ok
+      integer::maxi
+      real(8)::maxE
+      integer::i, j 
+      real(8):: x, E0, Ex, u, u1, u2     
+      real(8):: E1, E2
+      real(8)::temp
+      integer:: nc  ! counting # of ptcls in pstore
+      integer:: nw, icon
+      logical:: split 
+
+      real(8):: xcent, centval
+      xcent = sqrt(xth/xthu*xth*xthl)
+      centval =  crejK1(xcent)
+
+
+      E0 = inciptcl.fm.p(4) - inciptcl.mass
+      nout = nin
+      exist = 0
+      if( E0lab < E0th) return      !!!!!
+      nc = nin
+c            if pi/K is incident, regards the highest one as leading
+c            and avoid to modify 
+      if(leadingPiK .and. (inciptcl.code == kpion .or.
+     *     inciptcl.code == kkaon ) ) then
+c              find max energy ptcl index and E; eta cannot be incident
+         call cgetmaxptcl(pstore, nc, inciptcl.code, inciptcl.charge,
+     *        maxi, maxE)
+      else
+         maxi = 0
+      endif
+
+      do i = 1, nin
+         x = (pstore(i).fm.p(4)-pstore(i).mass)/E0
+         if( x > xth*xthl ) cycle
+         if( abs(mode) == 3 ) then
+            if( i /= maxi ) then
+c                softening
+               if(x > xth/xthu) then
+!                  modify high X of pi/K/eta
+                  if(pstore(i).code == kpion .or.
+     *                 pstore(i).code == kkaon 
+     *                 .or.   pstore(i).code ==  keta ) then
+                     nw = 0
+                     exist = exist + 1
+!                       judge to split this
+!!                     call cJudgeSplit(inciptcl, x,  split)
+                     call rndc(u)
+                     temp = crejK1(x)
+c                     split = u < 0.25*(temp/centval)
+c                     split = u < 0.125*(temp/centval)
+                     split = u < k1u*(temp/centval)
+                     if( .not. split ) cycle   
+
+                     call csplitMeson(pstore(i), E1, E2, icon)
+                     if(icon == 0) then
+                        modified = .true.
+                     ! split;  if impossilbe, do nothing
+                        nw = nw + 1
+                        work(nw) = pstore(i)
+                        work(nw).fm.p(4) = E1 + work(nw).mass 
+                        call cae2p(work(nw)) ! adjust momentum
+                        nw = nw + 1
+                        work(nw) = pstore(i)
+                        work(nw).fm.p(4) = E2 + work(nw).mass 
+                        call cae2p(work(nw))
+!                       original one is replaced by E1
+                        pstore(i) = work(1)
+!                       others are appended to  pstore. 
+                        do j = 2, nw ! altough always nw=2
+                           nc = nc + 1
+                           pstore(nc) = work(j)
+                        enddo
+                     endif
+                  endif
+               endif
+            endif
+         elseif( mode == 1 ) then
+            if( i /= maxi ) then
+c               discard all pi/K/eta with x>xth (except leanding)
+               if(pstore(i).code == kpion .or. pstore(i).code == kkaon 
+     *              .or.   pstore(i).code ==  keta ) then
+                  if( x > xth ) then
+c                   to neglect, put mass as E
+                     pstore(i).fm.p(4) = pstore(i).mass
+                     pstore(i).fm.p(1:3) = 0.
+                     modified = .true.
+                  endif
+               endif
+            endif
+         elseif( mode == 2 ) then 
+            if( i /= maxi) then
+c              discard only pi0/eta
+               if( ( pstore(i).code == kpion .and.
+     *              pstore(i).charge  == 0 ) .or.
+     *              pstore(i).code == keta ) then
+                  if(x> xth) then
+                     pstore(i).fm.p(4) = pstore(i).mass
+                     pstore(i).fm.p(1:3) = 0.    ! put zero energy
+                     modified = .true.
+                  endif
+               endif
+            endif
+         elseif( mode == 0 ) then
+c               do nothing
+         else
+            write(0,*) ' mode err=',mode, ' in csoftenPiK0'
+            stop
+         endif
+      enddo
+      if(abs(mode) == 3) then
+         nout = nc
+      endif
+      end subroutine csoftenPiK1
+
       subroutine csplitMeson(p, E1, E2, icon) 
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
       record /ptcl/p   ! input, a high energy ptcl
-      real(8),intent(out):: E1  ! split ptcl energy
+      real(8),intent(out):: E1  ! split ptcl energy KE
       real(8),intent(out):: E2  ! split ptcl
       integer,intent(out):: icon ! 0--> split ok, 1--> no split
       real(8):: u,  Emin, Em
@@ -331,18 +481,18 @@ c               do nothing
       do while(.not. ok)
          call rndc(u)
          u = u*(1.-xth) + xth
-         E1 = u* p.fm.p(4)
-         E2 = p.fm.p(4) - E1
-         if(E1 > p.mass .and.
-     *      E2 > p.mass ) then
+         E1 = u*( p.fm.p(4) - p.mass)
+         E2 = (p.fm.p(4) -p.mass) - E1
+!         if(E1 > p.mass .and.
+!     *      E2 > p.mass ) then
             ok = .true.
-         else
-            count = count + 1
-            if(count > 20) then
-               icon = 1
-               return
-            endif
-         endif
+!         else
+!            count = count + 1
+!            if(count > 20) then
+!               icon = 1
+!               return
+!            endif
+!         endif
       enddo
       icon = 0
       end subroutine csplitMeson
@@ -491,6 +641,14 @@ c       do modification  extract Pz>0  and Pz<0
              call creadParaL(vvalue, leadingPiK)
           case('useXinCMS')
              call creadParaL(vvalue, useXinCMS)
+          case('k1u')
+             call creadParaR(vvalue, k1u)
+          case('xthl')
+             call creadParaR(vvalue, xthl)
+          case('xthu')
+             call creadParaR(vvalue, xthu)
+          case('rejpw')
+             call creadParaR(vvalue, rejpw)
           end select
        enddo
        end       subroutine creadSoftenPara
@@ -509,6 +667,10 @@ c      *************
        call cwriteParaL(io,'special',special)
        call cwriteParaL(io,'leadingPiK',leadingPiK)
        call cwriteParaL(io,'useXinCMS', useXinCMS)
+       call cwriteParaR(io,'k1u', k1u)
+       call cwriteParaR(io,'xthl', xthl)
+       call cwriteParaR(io,'xthu', xthu)
+       call cwriteParaR(io,'rejpw', rejpw)
        end       subroutine  cwriteSoftenPara
 
 
@@ -626,7 +788,28 @@ c        ---------------------------------------------
       write(io,  *) ' ', vname,' ', logi,' /'
       end      subroutine cwriteParaL
 
-       function cgetParmN( io,  vname, vv ) result(ans)
+      function crejK1( x ) result(ans)
+      implicit none
+      real(8),intent(in):: x
+      real(8):: ans
+      ans = ( log(x/(xth/xthu)) * log((xth*xthl)/x) )**rejpw
+      end  function crejK1
+
+      function cxthu( E0 ) result(ans)
+      implicit none
+      real(8),intent(in):: E0 ! lab E0 in Gev
+      real(8):: ans   ! xthu
+      ans = 12.0*(E0/1.e8)**0.1
+      end      function cxthu
+
+      function ck1u( E0 ) result(ans)
+      implicit none
+      real(8),intent(in):: E0 ! lab E0 in Gev
+      real(8):: ans   !  k1u
+      ans = 0.3*(E0/1.e8)**0.09
+      end      function ck1u
+
+      function cgetParmN( io,  vname, vv ) result(ans)
 c          get parameter variable name and given value(s)  from io
        implicit none
        integer io
@@ -661,6 +844,18 @@ c          get parameter variable name and given value(s)  from io
        ans =.false.
        end function cgetParmN
 
-
+      function csoftenFixXth(E0)  result(xth)
+      implicit none
+      real(8),intent(in)::E0 ! proton/pi/K incident E. in GeV
+      real(8):: xth !
+!        fix the xth above which softening is performed
+!       at 10^12 eV:  0.1 
+!          10^13      0.063
+!          10^14      0.04
+!          10^16     0.01585
+!          10^17      0.01
+!          10^19      0.004
+      xth = 0.1d0/(E0/1000.d0)**0.2
+      end  function csoftenFixXth
 
       end module SoftenPiK
