@@ -5,22 +5,26 @@ c         by putting  Es = 0.
        namelist  /HParam/
      +  AnihiE, AtEnv, AtmosFile, BackAngLimit, BaseErg, BasePower
      +, BorderHeightH, BorderHeightL, Cekaon, Ceneuc, Cepic0
-     +, Charge2heavyG, Code2heavyG, Code2massN, Deltkp, Deltpip, Deltpp
-     +, DoNPadjust 
+     +, Charge2heavyG, Code2heavyG, Code2massN, DefofR
+     +, Deltkp, Deltpip, Deltpp
+     +, DoNPadjust, dpmRareDecay
      +, DpmFile, Ecrit, Efermi, Elund, Elund2, Elund3, EndLevel
      +, EndLevel2, ErrorOut, Es, Eta2Pi0, EthinRatio, EventNo
-     +, EventsInTheRun, ExactThick, FragmentTbl, Generate2, GeomagFile
+     +, EventsInTheRun, ExactThick, FragmentTbl, Generate2
+     +, GeomagFile
      +, HeavyG2charge, HeavyG2code, HeavyG2massN, HeavyG2symbol
-     +, HowGeomag, HowIntNuc, InclusiveFile, IncreaseXsec, KEminObs2
+     +, HowGeomag, HowIntNuc, HowEfield,  HowPhotoP, ASRforDPM
+     +, InclusiveFile, IncreaseXsec, KEminObs2
      +, KnockOnRatio, Knockon, Kpicns, Kpilog, LamorDiv, LpmBremEmin
      +, LpmPairEmin, LundPara, MagBrem, MagBremEmin, MagChgDist, MagD
      +, MagE, MagN, MagPair, MagPairEmin, MaxComptonE, MaxPhotoE
-     +, Excom1, Excom2,  Eabsorb,  HowPhotoP
-     +, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow, NoOfSites2
+     +, Excom1, Excom2,  Eabsorb 
+     +, Moliere, MuBr, MuNI, MuPr, Mudirp, MulLow, myEf, NoOfSites2
      +, OffsetHeight, PathLimit, PercentEnv, PrevEventNo, PtAvFrag
-     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse, SeedFileDev
-     +, SharpEnv, StepControl,SucInt, SucPw, TempDev, TraceDev
-     *, Truncc, Truncn
+     +, PtAvNonInteNuc, RatioToE0, RecoilKineMinE, Reverse
+     +, SeedFileDev
+     +, SharpEnv, StepControl,SucInt, SucPw, TempDev, TotXSopt
+     +, TraceDev,  Truncc, Truncn
      +, Truncx, UpsilonMin, UseRungeKutta, UserHookc, UserHooki
-     +, UserHookr, X0, XaxisFromSouth
+     +, UserHookr, X0, XaxisFromSouth, SxAbySxpOpt
      +, PhitsXs, JamXs,  AAXsec, JamFragment 
